@@ -5,7 +5,8 @@ from __future__ import annotations
 
 from typing import Callable, Hashable, Sequence
 
-from rapidfuzz._utils import is_none
+from rapidfuzz._common_py import conv_sequences
+from rapidfuzz._utils import is_none, setupPandas
 
 
 def _osa_distance_hyrroe2003(s1: Sequence[Hashable], s2: Sequence[Hashable]) -> int:
@@ -95,6 +96,7 @@ def distance(
         s1 = processor(s1)
         s2 = processor(s2)
 
+    s1, s2 = conv_sequences(s1, s2)
     dist = _osa_distance_hyrroe2003(s1, s2)
     return dist if (score_cutoff is None or dist <= score_cutoff) else score_cutoff + 1
 
@@ -135,6 +137,7 @@ def similarity(
         s1 = processor(s1)
         s2 = processor(s2)
 
+    s1, s2 = conv_sequences(s1, s2)
     maximum = max(len(s1), len(s2))
     dist = distance(s1, s2)
     sim = maximum - dist
@@ -172,6 +175,7 @@ def normalized_distance(
     norm_dist : float
         normalized distance between s1 and s2 as a float between 0 and 1.0
     """
+    setupPandas()
     if is_none(s1) or is_none(s2):
         return 1.0
 
@@ -179,6 +183,7 @@ def normalized_distance(
         s1 = processor(s1)
         s2 = processor(s2)
 
+    s1, s2 = conv_sequences(s1, s2)
     maximum = max(len(s1), len(s2))
     dist = distance(s1, s2)
     norm_dist = dist / maximum if maximum else 0
@@ -216,6 +221,7 @@ def normalized_similarity(
     norm_sim : float
         normalized similarity between s1 and s2 as a float between 0 and 1.0
     """
+    setupPandas()
     if is_none(s1) or is_none(s2):
         return 0.0
 
@@ -223,6 +229,7 @@ def normalized_similarity(
         s1 = processor(s1)
         s2 = processor(s2)
 
+    s1, s2 = conv_sequences(s1, s2)
     norm_dist = normalized_distance(s1, s2)
     norm_sim = 1.0 - norm_dist
     return norm_sim if (score_cutoff is None or norm_sim >= score_cutoff) else 0
